<xsl>

<define-script><![CDATA[
	function calcWidth(thisBid)
	{
		// Calculate the width of one bar of the graph
		var thisPrice, minPrice, maxPrice, price;
		var numBids, i;
		var allBids, aBid, aPrice;

		thisPrice = parseInt(thisBid.text, 10);

		allBids = thisBid.parent.parent;
		numBids = allBids.children.item("BID").length;

		// Find the highest and lowest bids for this item
		maxPrice = thisPrice;
		minPrice = thisPrice;
		for (i = 0; i < numBids; i++)
		{
			aBid = allBids.children.item("BID", i);
			aPrice = aBid.children.item("PRICE", 0);

			price = parseInt(aPrice.text, 10);
			if (price < minPrice) minPrice = price;
			if (price > maxPrice) maxPrice = price;
		}

		// Scale the return value with minPrice at 25% and maxPrice at 100%
		if (maxPrice == minPrice)
			return 100;
		else
			return (thisPrice - minPrice) * 75 / (maxPrice - minPrice) + 25;
	}

	function trimSeconds(time)
	{
		// This function trims the "seconds" off of a time string
		var i = 0;
		var start = 0;
		var end = 0;
		while (time.charAt(i) != ":")
			i++;
		i++;
		while (time.charAt(i) != ":")
			i++;
		start = i;
		while (time.charAt(i) != " ")
			i++;
		end = i;
		return time.substring(0,start) + time.substring(end, time.length);
	}
	]]></define-script>

	<!-- Root rule - start processing here -->
	<rule>
		<root/>
		<DIV font-family="Arial" font-size="12pt">
			<children/>
		</DIV>
	</rule>
	
	<rule>
		<target-element type="ITEM"/>
		<DIV font-weight="bold" font-size="14pt">
			<select-elements from="descendants">
				<target-element type="TITLE"/>
			</select-elements>
			<SPAN font-weight="normal"> by </SPAN>
			<select-elements from="descendants">
				<target-element type="ARTIST"/>
			</select-elements>
		</DIV>
		<select-elements from="descendants">
			<target-element type="BIDS"/>
		</select-elements>
	</rule>

	<!-- Rule for "BIDS" element -->
	<rule>
		<target-element type="BIDS"/>
		<DIV margin-top="4px">
			<children/>
		</DIV>
	</rule>

	<!-- Rule for "BID" elements -->
	<rule>
		<target-element type="BID"/>

		<DIV	position="relative"
				width='=formatNumber(calcWidth(this.children.item("PRICE",0)), "1") + "%"'
				height="1em"
				background-color="#FF8800"
				text-align="right"
				margin-top="2px">
			<select-elements from="children">
				<target-element type="PRICE"/>
			</select-elements>

			<select-elements from="children">
				<target-element type="BIDDER"/>
			</select-elements>

		</DIV>
	</rule>

	<!-- "BIDDER" element rule -->
	<rule>
		<target-element type="BIDDER"/>
		<DIV	margin-left="4px"
				position="absolute"
				top="0px"
				left='=formatNumber((50 > calcWidth(this.parent.children.item("PRICE",0))) ? 105 : 0, "1") + "%"'
				width='=formatNumber((50 > calcWidth(this.parent.children.item("PRICE",0))) ? (10000/calcWidth(this.parent.children.item("PRICE",0)) - 110) : 100, "1") + "%"'
				text-align="left">
			<SPAN font-weight="bold"><children/></SPAN>
			<SPAN font-style="italic" font-size="10pt">
				(<eval>trimSeconds(this.parent.children.item("TIME",0).text)</eval>)
			</SPAN>
		</DIV>
	</rule>

	<!-- "Price" element rule -->
	<rule>
		<target-element type="PRICE"/>
		<SPAN font-weight="bold">$<children/></SPAN>
	</rule>

</xsl>
